cmoncrawl.processor.pipeline.extractor.HTMLExtractor.filter\_soup
=================================================================

.. currentmodule:: cmoncrawl.processor.pipeline.extractor

.. automethod:: HTMLExtractor.filter_soup